/**
 * Copyright (c) 2012 EBM WebSourcing, 2012-2015 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see <http://www.gnu.org/licenses/>
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.admin.junit;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;

import org.ow2.petals.admin.api.ArtifactAdministration;
import org.ow2.petals.admin.api.artifact.Artifact;
import org.ow2.petals.admin.api.artifact.lifecycle.ArtifactLifecycle;
import org.ow2.petals.admin.api.artifact.lifecycle.ArtifactLifecycleFactory;
import org.ow2.petals.admin.api.exception.ArtifactAdministrationException;
import org.ow2.petals.admin.api.exception.ArtifactNotFoundException;
import org.ow2.petals.admin.api.exception.ArtifactTypeIsNeededException;

/**
 * 
 * @author Mathieu CARROLLE - EBM WebSourcing
 * @author Christophe DENEUX - Linagora
 * 
 */
public class ArtifactAdministrationMock extends ArtifactAdministration {

    private final ArtifactRegistry artifactRegistry;

    public ArtifactAdministrationMock(final ArtifactRegistry artifactRegistry,
            final ArtifactLifecycleFactory artifactLifecycle) {
        super(artifactLifecycle);
        this.artifactRegistry = artifactRegistry;
    }

    @Override
    public void stopAndUndeployAllArtifacts() throws ArtifactAdministrationException {

        for (final Artifact a : this.artifactRegistry.list()) {
            final ArtifactLifecycle aLifecycle = this.artifactLifecycleFactory.createLifecycle(a);
            aLifecycle.stop();
            aLifecycle.undeploy();
        }
    }

    @Override
    public List<Artifact> listArtifacts() throws ArtifactAdministrationException {
        return Arrays.asList(this.artifactRegistry.list());
    }

    @Override
    public Artifact getArtifact(final String type, final String name, final String version)
            throws ArtifactAdministrationException {
        assert name != null;

        final Artifact[] artifacts = this.artifactRegistry.list();
        final List<Artifact> artifactsMatchingName = new ArrayList<Artifact>();
        for (Artifact artifact : artifacts) {
            if ((type == null || (type != null && artifact.getType().equals(type))) && artifact.getName().equals(name)
                    && (version == null || (version != null && artifact.getVersion().equals(version)))) {
                artifactsMatchingName.add(artifact);
            }
        }
        if (artifactsMatchingName.size() == 0) {
            throw new ArtifactNotFoundException(type, name, version);
        } else if (artifactsMatchingName.size() > 1) {
            throw new ArtifactTypeIsNeededException(name);
        } else {
            return artifactsMatchingName.get(0);
        }
    }

}
