/**
 * Copyright (c) 2012 EBM WebSourcing, 2012-2015 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see <http://www.gnu.org/licenses/>
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.admin.junit;

import java.net.URL;

import org.ow2.petals.admin.api.artifact.ArtifactState.State;
import org.ow2.petals.admin.api.artifact.Component;
import org.ow2.petals.admin.api.artifact.lifecycle.ComponentLifecycle;
import org.ow2.petals.admin.api.exception.ArtifactAdministrationException;
import org.ow2.petals.admin.api.exception.ArtifactNotFoundException;
import org.ow2.petals.admin.api.exception.ArtifactUnsupportedOperationException;

/**
 * 
 * @author "Mathieu CARROLLE - EBM WebSourcing"
 */
public class ComponentLifecycleMock implements ComponentLifecycle {

    private final ArtifactRegistry artifactRegistry;

    private final Component component;

    public ComponentLifecycleMock(final Component c, final ArtifactRegistry artifactRegistry) {
        this.component = c;
        this.artifactRegistry = artifactRegistry;
    }

    @Override
    public void deploy(final URL artifactUrl) throws ArtifactAdministrationException {
        this.artifactRegistry.add(getComponent());
    }

    @Override
    public void start() throws ArtifactAdministrationException {
        final Component found = (Component) this.artifactRegistry.get(getComponent());
        if (found == null) {
            throw new ArtifactNotFoundException(this.component.getType(), this.component.getName(),
                    this.component.getVersion());
        }
        found.setState(State.STARTED);

    }

    @Override
    public void stop() throws ArtifactAdministrationException {
        final Component found = (Component) this.artifactRegistry.get(getComponent());
        if (found == null) {
            throw new ArtifactNotFoundException(this.component.getType(), this.component.getName(),
                    this.component.getVersion());
        }
        found.setState(State.STOPPED);
    }

    @Override
    public void undeploy() throws ArtifactAdministrationException {
        this.artifactRegistry.remove(getComponent());
    }

    @Override
    public void updateState() throws ArtifactAdministrationException {
        final Component found = (Component) this.artifactRegistry.get(getComponent());
        if (found == null) {
            throw new ArtifactNotFoundException(this.component.getType(), this.component.getName(),
                    this.component.getVersion());
        }
        getComponent().setState(found.getState());
    }

    @Override
    public Component getComponent() {
        return this.component;
    }

    @Override
    public void reloadConfiguration() throws ArtifactNotFoundException, ArtifactUnsupportedOperationException,
            ArtifactAdministrationException {
        final Component found = (Component) this.artifactRegistry.get(getComponent());
        if (found == null) {
            throw new ArtifactNotFoundException(this.component.getType(), this.component.getName(),
                    this.component.getVersion());
        }
    }
}